from flask import Flask, jsonify
import geopandas as gpd
import matplotlib.pyplot as plt
import matplotlib
from flask_cors import CORS

import requests
from io import BytesIO
import base64
matplotlib.use('Agg')

app = Flask(__name__)
CORS(app)

def generate_image(gdf):
    fig, ax = plt.subplots(figsize=(10, 10))
    gdf.plot(ax=ax)
    # Save the plot to a BytesIO object
    image_stream = BytesIO()
    plt.savefig(image_stream, format='png', dpi=300, bbox_inches='tight')
    image_stream.seek(0)

    # Encode the image to base64 for embedding in HTML
    encoded_image = base64.b64encode(image_stream.read()).decode('utf-8')
    return encoded_image

@app.route("/")
def hello_world():
    print('hee')

    # pre Step: getting the path lineString coordinates
    api_url = "http://localhost:3000/getShortestPath?productCoordinates=[104.5,%202]&startingPointCoordinates=[100,%201.35]"

    response = requests.get(api_url)
    coordinates = response.json()
    print(str(coordinates))
    
    # Step 1: Read the GeoJSON file using GeoPandas
    # https://en.wikipedia.org/wiki/GeoJSON
    geojson_file = "./sample.json"
    geojson_str = '''
    {
    "type": "FeatureCollection",
    "features": [
        {
        "type": "Feature",    
        "geometry": { "type": "Point", "coordinates": [102.0, 0.5] },
        "properties": { "prop0": "value0" }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [101.1, 0.0],
                [104.0, 0.0],
                [104.0, 1.0],
                [101.1, 1.0],
                [101.1, 0.0]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [104.1, 0.0],
                [107.0, 0.0],
                [107.0, 1.0],
                [104.1, 1.0],
                [104.1, 0.0]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [100.0, 0.0],
                [101.0, 0.0],
                [101.0, 1.0],
                [100.0, 1.0],
                [100.0, 0.0]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },


        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [100.0, 1.7],
                [102.0, 1.7],
                [102.0, 3.0],
                [100.0, 3.0],
                [100.0, 1.7]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [102.1, 1.7],
                [103.1, 1.7],
                [103.1, 3.0],
                [102.1, 3.0],
                [102.1, 1.7]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [103.2, 2.4],
                [104.5, 2.4],
                [104.5, 3.0],
                [103.2, 3.0],
                [103.2, 2.4]
            ]
            ]
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [103.2, 1.7],
                [104.5, 1.7],
                [104.5, 2.3],
                [103.2, 2.3],
                [103.2, 1.7]
            ]
            ]
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [105.2, 1.7],
                [107.0, 1.7],
                [107.0, 3.0],
                [105.2, 3.0],
                [105.2, 1.7]
            ]
            ]
        }
        },




        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [100.0, 3.6],
                [101.4, 3.6],
                [101.4, 4.9],
                [100.0, 4.9],
                [100.0, 3.6]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [102.1, 3.6],
                [103.1, 3.6],
                [103.1, 4.9],
                [102.1, 4.9],
                [102.1, 3.6]
            ]
            ]
        },
        "properties": {
            "prop0": "value0",
            "prop1": { "this": "that" }
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [103.2, 3.6],
                [104.5, 3.6],
                [104.5, 4.9],
                [103.2, 4.9],
                [103.2, 3.6]
            ]
            ]
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "Polygon",
            "coordinates": [
            [
                [105.2, 3.6],
                [107.0, 3.6],
                [107.0, 4.9],
                [105.2, 4.9],
                [105.2, 3.6]
            ]
            ]
        }
        },
        {
        "type": "Feature",
        "geometry": {
            "type": "MultiPoint",
            "coordinates": [  
            [101.75, 5],
            [101.75, 4.3],
            [101.4, 4.3],
            [100.5, 3.3],
            [100.5, 3.0],
            [100, 3.3],
            [101.75, 3.3],
            [104.85, 3.3],
            [102.7, 3.3],
            [102.7, 3.6],
            [102.7, 3.0],
            [103.7, 3.3],
            [103.7, 3.6],
            [103.7, 3.0],
            [106.2, 3.3],
            [107, 3.3],
            [106.2, 3.0],
            [104.85, 4.3],
            [105.2, 4.3],
            [104.85, 5],
            [104.85, 2],
            [104.50, 2],
            [104.85, 1.35],
            [105.5, 1.35],
            [105.5, 1.0],
            [107, 1.35],
            [102.5, 1.35],
            [102.5, 1.0],
            [100.5, 1.35],
            [100.5, 1.0],
            [100, 1.35]
            ]
        }
        },'''+''' {
        "type": "Feature",
        "geometry": {
            "type": "LineString",
            "coordinates": 
            '''+str(coordinates)+'''
        }
        }
        '''+'''
    ]
    }'''

    gdf = gpd.read_file(geojson_str, driver='GeoJSON')

    # Step 2: Create a plot using Matplotlib
    img = generate_image(gdf)

    return jsonify({"image":img})




